@@ -75,7 +75,7 @@ pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<Trad
             TradeSide::Buy
         },
         trade_id: raw_trade.trade_id.to_string(),
-        raw: serde_json::to_value(&raw_trade).unwrap(),
+        json: msg.to_string(),
     };
 
     Ok(vec![trade])
@@ -137,7 +137,7 @@ pub(crate) fn parse_l2(
                 .map(|x| parse_order(x))
                 .collect(),
             snapshot,
-            raw: serde_json::from_str(msg)?,
+            json: msg.to_string(),
         };
 
         Ok(vec![orderbook])
@@ -167,7 +167,7 @@ pub(crate) fn parse_l2(
                 .map(|x| parse_change(x))
                 .collect(),
             snapshot,
-            raw: serde_json::from_str(msg)?,
+            json: msg.to_string(),
         };
 
         Ok(vec![orderbook])
