@@ -56,7 +56,7 @@ pub(super) fn parse_trade(msg: &str) -> Result<Vec<TradeMsg>> {
     };
     let pair = crypto_pair::normalize_pair(symbol, EXCHANGE_NAME).unwrap();
 
-    let trades: Vec<TradeMsg> = ws_msg
+    let mut trades: Vec<TradeMsg> = ws_msg
         .tick
         .data
         .into_iter()
@@ -77,10 +77,13 @@ pub(super) fn parse_trade(msg: &str) -> Result<Vec<TradeMsg>> {
                 TradeSide::Buy
             },
             trade_id: raw_trade.tradeId.to_string(),
-            raw: serde_json::to_value(&raw_trade).unwrap(),
+            json: serde_json::to_string(&raw_trade).unwrap(),
         })
         .collect();
 
+    if trades.len() == 1 {
+        trades[0].json = msg.to_string();
+    }
     Ok(trades)
 }
 
@@ -115,7 +118,7 @@ pub(crate) fn parse_l2(msg: &str) -> Result<Vec<OrderBookMsg>> {
         asks: ws_msg.tick.asks.iter().map(|x| parse_order(x)).collect(),
         bids: ws_msg.tick.bids.iter().map(|x| parse_order(x)).collect(),
         snapshot: false,
-        raw: serde_json::from_str(msg)?,
+        json: msg.to_string(),
     };
 
     Ok(vec![orderbook])
