@@ -89,7 +89,7 @@ pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<Trad
             TradeSide::Buy
         },
         trade_id: raw_trade.sequence.to_string(),
-        raw: serde_json::to_value(&raw_trade).unwrap(),
+        json: msg.to_string(),
     };
 
     Ok(vec![trade])
@@ -137,7 +137,7 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
         asks,
         bids,
         snapshot: false,
-        raw: serde_json::from_str(msg)?,
+        json: msg.to_string(),
     };
 
     Ok(vec![orderbook])
